Condoor 
=======

.. image:: https://travis-ci.org/kstaniek/condoor.svg?branch=master
    :target: https://travis-ci.org/kstaniek/condoor

Condoor is a python module providing the connection method to Cisco devices.
It supports keyring for password management and multiple jump hosts.

Installation
------------

The module can be installed from the source using::

    python setup.py install


or from PyPI repository::

    pip install condoor


The required packages will be installed automatically.

Documentation
=============

`Docs on ReadTheDocs <http://condoor.readthedocs.org/>`_


Required packages
=================

* pexpect
* keyring (optional)


